@@ -22,12 +22,9 @@
  *          Xavier Claessens <xclaesse@gmail.com>
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <glib/gi18n.h>
-#include <gtk/gtk.h>
-
-#include <libempathy-gtk/empathy-ui-utils.h>
 
 #include "empathy-about-dialog.h"
 
